@@ -93,6 +93,12 @@ class DbTransactionError(DbException):
     pass
 
 
+class DbSchemaLockedError(DbApplicationError):
+    """Raised when attempting to modify schema while schema is locked."""
+
+    pass
+
+
 class DuplicateRowsFoundError(Exception):
     """Multiple rows found when expecting single result."""
 
@@ -125,5 +131,6 @@ __all__ = [
     "DbDataIntegrityError",
     "DbQueryError",
     "DbTransactionError",
+    "DbSchemaLockedError",
     "DuplicateRowsFoundError",
 ]
