@@ -69,7 +69,7 @@ class SQL(BaseSQLDialect):
 
     default_schema = "public"
 
-    ApplicationErrorCodes = ["22P02", "42883", "42501", "42601", "25P01", "25P02"]
+    ApplicationErrorCodes = ["22P02", "42883", "42501", "42601", "25P01", "25P02", "42804"]  # Added 42804 for datatype mismatch
 
     DatabaseMissingErrorCodes = ["3D000"]
     TableMissingErrorCodes = ["42P01"]
@@ -296,11 +296,44 @@ class SQL(BaseSQLDialect):
         else:
             sql_parts["FROM"].append(TableHelper.quote(table))
 
-        # WHERE
+        # WHERE - Enhanced validation to prevent malformed SQL
         if where:
             if isinstance(where, str):
+                # Validate string WHERE clauses to prevent malformed SQL
+                where_stripped = where.strip()
+                if not where_stripped:
+                    raise ValueError("WHERE clause cannot be empty string.")
+                # Check for boolean literals first (includes '1' and '0')
+                if where_stripped in ('True', 'False', '1', '0'):
+                    raise ValueError(
+                        f"Invalid WHERE clause: '{where}'. "
+                        "Boolean literals alone are not valid WHERE clauses. "
+                        "Use complete SQL expressions like 'sys_active = true' instead."
+                    )
+                # Then check for other numeric values (excluding '1' and '0' already handled above)
+                elif where_stripped.isdigit():
+                    raise ValueError(
+                        f"Invalid WHERE clause: '{where}'. "
+                        "Bare integers are not valid WHERE clauses. "
+                        "Use a dictionary like {{'sys_id': {where_stripped}}} or "
+                        f"a complete SQL expression like 'sys_id = {where_stripped}' instead."
+                    )
                 sql_parts["WHERE"].append(where)
-            else:
+            elif isinstance(where, (int, float, bool)):
+                # Handle primitive types that should be converted to proper WHERE clauses
+                suggested_fix = "{'sys_id': " + str(where) + "}" if isinstance(where, int) else "complete SQL expression"
+                raise ValueError(
+                    f"Invalid WHERE clause: {where} (type: {type(where).__name__}). "
+                    f"Primitive values cannot be WHERE clauses directly. "
+                    f"Use a dictionary like {suggested_fix} or a complete SQL string instead. "
+                    f"This error prevents PostgreSQL 'argument of WHERE must be type boolean' errors."
+                )
+            elif isinstance(where, Mapping):
+                # Convert dictionary to predicate list
+                new_where = []
+                for key, val in where.items():
+                    new_where.append(th.make_predicate(key, val))
+                where = new_where
                 for pred, val in where:
                     sql_parts["WHERE"].append(pred)
                     if val is None:
@@ -309,6 +342,22 @@ class SQL(BaseSQLDialect):
                         vals.extend(val)
                     else:
                         vals.append(val)
+            else:
+                # Handle list of tuples or other iterable
+                try:
+                    for pred, val in where:
+                        sql_parts["WHERE"].append(pred)
+                        if val is None:
+                            pass
+                        elif isinstance(val, tuple):
+                            vals.extend(val)
+                        else:
+                            vals.append(val)
+                except (TypeError, ValueError) as e:
+                    raise ValueError(
+                        f"Invalid WHERE clause format: {where}. "
+                        "Expected dictionary, list of (predicate, value) tuples, or SQL string."
+                    ) from e
 
         # GROUP BY
         if groupby:
@@ -437,17 +486,53 @@ class SQL(BaseSQLDialect):
                     for key, val in where.items():
                         new_where.append(th.make_predicate(key, val))
                     where = new_where
-                if isinstance(where, str):
+                elif isinstance(where, str):
+                    # Enhanced validation for string WHERE clauses
+                    where_stripped = where.strip()
+                    if not where_stripped:
+                        raise ValueError("WHERE clause cannot be empty string.")
+                    # Check for boolean literals first (includes '1' and '0')
+                    if where_stripped in ('True', 'False', '1', '0'):
+                        raise ValueError(
+                            f"Invalid WHERE clause: '{where}'. "
+                            "Boolean literals alone are not valid WHERE clauses. "
+                            "Use complete SQL expressions like 'sys_active = true' instead."
+                        )
+                    # Then check for other numeric values (excluding '1' and '0' already handled above)
+                    elif where_stripped.isdigit():
+                        raise ValueError(
+                            f"Invalid WHERE clause: '{where}'. "
+                            "Bare integers are not valid WHERE clauses. "
+                            f"Use a dictionary like {{'sys_id': {where_stripped}}} or "
+                            f"a complete SQL expression like 'sys_id = {where_stripped}' instead."
+                        )
                     where_clauses.append(where)
-                else:
-                    for pred, value in where:
-                        where_clauses.append(pred)
-                        if value is None:
-                            pass
-                        elif isinstance(value, tuple):
-                            vals.extend(value)
-                        else:
-                            vals.append(value)
+                elif isinstance(where, (int, float, bool)):
+                    # Handle primitive types that should be converted to proper WHERE clauses
+                    suggested_fix = "{'sys_id': " + str(where) + "}" if isinstance(where, int) else "complete SQL expression"
+                    raise ValueError(
+                        f"Invalid WHERE clause: {where} (type: {type(where).__name__}). "
+                        f"Primitive values cannot be WHERE clauses directly. "
+                        f"Use a dictionary like {suggested_fix} or a complete SQL string instead. "
+                        f"This error prevents PostgreSQL 'argument of WHERE must be type boolean' errors."
+                    )
+                
+                # Process the where clause if it's a list of tuples
+                if not isinstance(where, str):
+                    try:
+                        for pred, value in where:
+                            where_clauses.append(pred)
+                            if value is None:
+                                pass
+                            elif isinstance(value, tuple):
+                                vals.extend(value)
+                            else:
+                                vals.append(value)
+                    except (TypeError, ValueError) as e:
+                        raise ValueError(
+                            f"Invalid WHERE clause format: {where}. "
+                            "Expected dictionary, list of (predicate, value) tuples, or SQL string."
+                        ) from e
             if not where_clauses:
                 raise ValueError(
                     "No WHERE clause could be constructed. Update would affect all rows."
